==> docx-rs-0.3.0.crate: docx-rs-0.3.0/src/documents/elements/mod.rs <==
mod a_graphic;
mod a_graphic_data;
mod abstract_numbering;
mod based_on;
mod bold;
mod bold_cs;
mod bookmark_end;
mod bookmark_start;
mod br;
mod character_spacing;
mod color;
mod comment;
mod comment_extended;
mod comment_range_end;
mod comment_range_start;
mod default_tab_stop;
mod delete;
mod delete_text;
mod div;
mod doc_defaults;
mod doc_grid;
mod doc_id;
mod doc_var;
mod drawing;
mod font;
mod grid_span;
mod header_reference;
mod footer_reference;
mod highlight;
mod indent;
mod indent_level;
mod insert;
mod italic;
mod italic_cs;
mod justification;
mod level;
mod level_jc;
mod level_override;
mod level_restart;
mod level_text;
mod line_spacing;
mod mc_fallback;
mod name;
mod next;
mod number_format;
mod numbering;
mod numbering_id;
mod numbering_property;
mod outline_lvl;
mod page_margin;
mod page_size;
mod paragraph;
mod paragraph_property;
mod paragraph_style;
mod pic;
mod q_format;
mod run;
mod run_fonts;
mod run_property;
mod run_property_default;
mod section;
mod section_property;
mod shading;
mod start;
mod style;
mod sz;
mod sz_cs;
mod tab;
mod table;
mod table_borders;
mod table_cell;
mod table_cell_borders;
mod table_cell_margins;
mod table_cell_property;
mod table_cell_width;
mod table_grid;
mod table_indent;
mod table_layout;
mod table_property;
mod table_row;
mod table_row_property;
mod table_style;
mod table_width;
mod text;
mod text_border;
mod text_box_content;
mod text_direction;
mod underline;
mod v_align;
mod vanish;
mod vert_align;
mod vertical_merge;
mod wp_anchor;
mod wps_shape;
mod wps_text_box;
mod zoom;

pub use a_graphic::*;
pub use a_graphic_data::*;
pub use abstract_numbering::*;
pub use based_on::*;
pub use bold::*;
pub use bold_cs::*;
pub use bookmark_end::*;
pub use bookmark_start::*;
pub use br::*;
pub use character_spacing::*;
pub use color::*;
pub use comment::*;
pub use comment_extended::*;
pub use comment_range_end::*;
pub use comment_range_start::*;
pub use default_tab_stop::*;
pub use delete::*;
pub use delete_text::*;
pub use div::*;
pub use doc_defaults::*;
pub use doc_grid::*;
pub use doc_id::*;
pub use doc_var::*;
pub use drawing::*;
pub use font::*;
pub use grid_span::*;
pub use header_reference::*;
pub use footer_reference::*;
pub use highlight::*;
pub use indent::*;
pub use indent_level::*;
pub use insert::*;
pub use italic::*;
pub use italic_cs::*;
pub use justification::*;
pub use level::*;
pub use level_jc::*;
pub use level_override::*;
pub use level_restart::*;
pub use level_text::*;
pub use line_spacing::*;
pub use mc_fallback::*;
pub use name::*;
pub use next::*;
pub use number_format::*;
pub use numbering::*;
pub use numbering_id::*;
pub use numbering_property::*;
pub use outline_lvl::*;
pub use page_margin::*;
pub use page_size::*;
pub use paragraph::*;
pub use paragraph_property::*;
pub use paragraph_style::*;
pub use pic::*;
pub use q_format::*;
pub use run::*;
pub use run_fonts::*;
pub use run_property::*;
pub use run_property_default::*;
pub use section::*;
pub use section_property::*;
pub use shading::*;
pub use start::*;
pub use style::*;
pub use sz::*;
pub use sz_cs::*;
pub use tab::*;
pub use table::*;
pub use table_borders::*;
pub use table_cell::*;
pub use table_cell_borders::*;
pub use table_cell_margins::*;
pub use table_cell_property::*;
pub use table_cell_width::*;
pub use table_grid::*;
pub use table_indent::*;
pub use table_layout::*;
pub use table_property::*;
pub use table_row::*;
pub use table_row_property::*;
pub use table_style::*;
pub use table_width::*;
pub use text::*;
pub use text_border::*;
pub use text_box_content::*;
pub use text_direction::*;
pub use underline::*;
pub use v_align::*;
pub use vanish::*;
pub use vert_align::*;
pub use vertical_merge::*;
pub use wp_anchor::*;
pub use wps_shape::*;
pub use wps_text_box::*;
pub use zoom::*;

==> docx-rs-0.3.2.crate: docx-rs-0.3.2/src/documents/elements/mod.rs <==
mod a_graphic;
mod a_graphic_data;
mod abstract_numbering;
mod based_on;
mod bold;
mod bold_cs;
mod bookmark_end;
mod bookmark_start;
mod br;
mod character_spacing;
mod color;
mod comment;
mod comment_extended;
mod comment_range_end;
mod comment_range_start;
mod data_binding;
mod default_tab_stop;
mod delete;
mod delete_text;
mod div;
mod doc_defaults;
mod doc_grid;
mod doc_id;
mod doc_var;
mod drawing;
mod fld_char;
mod font;
mod footer_reference;
mod grid_span;
mod header_reference;
mod highlight;
mod indent;
mod indent_level;
mod insert;
mod instr_text;
mod italic;
mod italic_cs;
mod justification;
mod level;
mod level_jc;
mod level_override;
mod level_restart;
mod level_text;
mod line_spacing;
mod mc_fallback;
mod name;
mod next;
mod number_format;
mod numbering;
mod numbering_id;
mod numbering_property;
mod outline_lvl;
mod page_margin;
mod page_size;
mod paragraph;
mod paragraph_property;
mod paragraph_style;
mod pic;
mod q_format;
mod run;
mod run_fonts;
mod run_property;
mod run_property_default;
mod section;
mod section_property;
mod shading;
mod start;
mod structured_data_tag;
mod structured_data_tag_property;
mod style;
mod sz;
mod sz_cs;
mod tab;
mod table;
mod table_borders;
mod table_cell;
mod table_cell_borders;
mod table_cell_margins;
mod table_cell_property;
mod table_cell_width;
mod table_grid;
mod table_indent;
mod table_layout;
mod table_of_contents;
mod table_property;
mod table_row;
mod table_row_property;
mod table_style;
mod table_width;
mod text;
mod text_border;
mod text_box_content;
mod text_direction;
mod underline;
mod v_align;
mod vanish;
mod vert_align;
mod vertical_merge;
mod wp_anchor;
mod wps_shape;
mod wps_text_box;
mod zoom;

pub use a_graphic::*;
pub use a_graphic_data::*;
pub use abstract_numbering::*;
pub use based_on::*;
pub use bold::*;
pub use bold_cs::*;
pub use bookmark_end::*;
pub use bookmark_start::*;
pub use br::*;
pub use character_spacing::*;
pub use color::*;
pub use comment::*;
pub use comment_extended::*;
pub use comment_range_end::*;
pub use comment_range_start::*;
pub use data_binding::*;
pub use default_tab_stop::*;
pub use delete::*;
pub use delete_text::*;
pub use div::*;
pub use doc_defaults::*;
pub use doc_grid::*;
pub use doc_id::*;
pub use doc_var::*;
pub use drawing::*;
pub use fld_char::*;
pub use font::*;
pub use footer_reference::*;
pub use grid_span::*;
pub use header_reference::*;
pub use highlight::*;
pub use indent::*;
pub use indent_level::*;
pub use insert::*;
pub use instr_text::*;
pub use italic::*;
pub use italic_cs::*;
pub use justification::*;
pub use level::*;
pub use level_jc::*;
pub use level_override::*;
pub use level_restart::*;
pub use level_text::*;
pub use line_spacing::*;
pub use mc_fallback::*;
pub use name::*;
pub use next::*;
pub use number_format::*;
pub use numbering::*;
pub use numbering_id::*;
pub use numbering_property::*;
pub use outline_lvl::*;
pub use page_margin::*;
pub use page_size::*;
pub use paragraph::*;
pub use paragraph_property::*;
pub use paragraph_style::*;
pub use pic::*;
pub use q_format::*;
pub use run::*;
pub use run_fonts::*;
pub use run_property::*;
pub use run_property_default::*;
pub use section::*;
pub use section_property::*;
pub use shading::*;
pub use start::*;
pub use structured_data_tag::*;
pub use structured_data_tag_property::*;
pub use style::*;
pub use sz::*;
pub use sz_cs::*;
pub use tab::*;
pub use table::*;
pub use table_borders::*;
pub use table_cell::*;
pub use table_cell_borders::*;
pub use table_cell_margins::*;
pub use table_cell_property::*;
pub use table_cell_width::*;
pub use table_grid::*;
pub use table_indent::*;
pub use table_layout::*;
pub use table_of_contents::*;
pub use table_property::*;
pub use table_row::*;
pub use table_row_property::*;
pub use table_style::*;
pub use table_width::*;
pub use text::*;
pub use text_border::*;
pub use text_box_content::*;
pub use text_direction::*;
pub use underline::*;
pub use v_align::*;
pub use vanish::*;
pub use vert_align::*;
pub use vertical_merge::*;
pub use wp_anchor::*;
pub use wps_shape::*;
pub use wps_text_box::*;
pub use zoom::*;
